@@ -31,14 +31,15 @@ __xiuxian_notes__ = f"""
 1、我要修仙：进入修仙模式
 2、我的修仙信息：获取修仙数据
 3、修仙签到：获取灵石及修为
-4、重入仙途：重置灵根数据，每次100灵石
-5、金银阁：猜大小，赌灵石
+4、重入仙途：重置灵根数据，每次{XiuConfig().remake}灵石
+5、金银阁：猜大小/数字，赌灵石
 6、改名xx：修改你的道号
 7、突破：修为足够后，可突破境界（一定几率失败）
-8、闭关、出关：修炼增加修为，挂机功能
+8、闭关、出关、灵石出关：修炼增加修为，挂机功能
 9、送灵石+数量+道号或者艾特对应人
 10、排行榜：修仙排行榜，灵石排行榜
 11、悬赏令：获取任务单，接取任务示例：悬赏令接取1， 结算命令示例：悬赏令结算
+12、偷灵石：偷灵石@xxx
 -简易灵根帮助-
 混沌灵根>融合灵根>超灵根>龙灵根>天灵根>变异灵根>真灵根>伪灵根
 """.strip()
@@ -74,7 +75,7 @@ sql_message = XiuxianDateManage()  # sql类
 
 
 @run_xiuxian.handle()
-async def _(event: GroupMessageEvent):
+async def _(bot: Bot, event: GroupMessageEvent):
     """加入修仙"""
     user_id = event.get_user_id()
     user_name = (
@@ -93,42 +94,41 @@ async def _(event: GroupMessageEvent):
 
 
 @xiuxian_message.handle()
-async def _(event: GroupMessageEvent):
+async def _(bot: Bot, event: GroupMessageEvent):
     """我的修仙信息"""
-    user_id = event.get_user_id()
-    mess = sql_message.get_user_message(user_id)
+    try:
+        user_id, group_id, mess = await data_check(bot, event)
+    except MsgError:
+        return
 
-    if mess:
-        user_name = mess.user_name
-        if user_name:
-            pass
+    user_name = mess.user_name
+    if user_name:
+        pass
+    else:
+        user_name = "无名氏(发送改名+道号更新)"
+    level_rate = sql_message.get_root_rate(mess.root_type)  # 灵根倍率
+    realm_rate = jsondata.level_data()[mess.level]["spend"]  # 境界倍率
+
+    # 判断突破的修为
+    list_all = len(OtherSet().level) - 1
+    now_index = OtherSet().level.index(mess.level)
+    if list_all == now_index:
+        get_exp = "位面至高"
+    else:
+        is_updata_level = OtherSet().level[now_index + 1]
+        need_exp = sql_message.get_level_power(is_updata_level)
+        if need_exp - mess.exp > 0:
+            get_exp = "还需{}修为可突破".format(need_exp - mess.exp)
         else:
-            user_name = "无名氏(发送改名+道号更新)"
-        level_rate = sql_message.get_root_rate(mess.root_type)  # 灵根倍率
-        realm_rate = jsondata.level_data()[mess.level]["spend"]  # 境界倍率
+            get_exp = "可突破！"
 
-        # 判断突破的修为
-        list_all = len(OtherSet().level) - 1
-        now_index = OtherSet().level.index(mess.level)
-        if list_all == now_index:
-            get_exp = "位面至高"
-        else:
-            is_updata_level = OtherSet().level[now_index + 1]
-            need_exp = XiuxianDateManage().get_level_power(is_updata_level)
-            if need_exp - mess.exp > 0:
-                get_exp = "还需{}修为可突破".format(need_exp - mess.exp)
-            else:
-                get_exp = "可突破！"
-
-        msg = f"""{user_name}道友的信息
+    msg = f"""{user_name}道友的信息
 灵根为：{mess.root}({mess.root_type}+{int(level_rate * 100)}%)
 当前境界：{mess.level}(境界+{int(realm_rate * 100)}%)
 当前灵石：{mess.stone}
 当前修为：{mess.exp}(修炼效率+{int((level_rate * realm_rate) * 100)}%)
 突破状态：{get_exp}
 你的战力为：{int(mess.exp * level_rate * realm_rate)}"""
-    else:
-        msg = "未曾踏入修仙世界，输入 我要修仙 加入我们，看破这世间虚妄!"
 
     await run_xiuxian.finish(msg, at_sender=True)
 
@@ -185,18 +185,18 @@ async def _(event: GroupMessageEvent):
         sql_message.update_ls(user_id, price_num, 1)
         await dice.send(msg)
         await dice.finish(
-            "最终结果为{}，你猜对了，收获灵石{}块".format(value, price_num), at_sender=True
+            "最终结果为{}，你猜对了，收获灵石{}块".format(value, price_num*2), at_sender=True
         )
     elif value <= 3 and str(message) == "小":
         del race[group_id]
         sql_message.update_ls(user_id, price_num, 1)
         await dice.send(msg)
         await dice.finish(
-            "最终结果为{}，你猜对了，收获灵石{}块".format(value, price_num), at_sender=True
+            "最终结果为{}，你猜对了，收获灵石{}块".format(value, price_num*2), at_sender=True
         )
     elif str(value) == str(message):
         del race[group_id]
-        sql_message.update_ls(user_id, price_num * 6, 1)
+        sql_message.update_ls(user_id, price_num * 5, 1)
         await dice.send(msg)
         await dice.finish(
             "最终结果为{}，你猜对了，收获灵石{}块".format(value, price_num * 6), at_sender=True
@@ -334,8 +334,13 @@ async def _(event: GroupMessageEvent, args: Message = CommandArg()):
     """修改道号"""
     user_id = event.get_user_id()
     user_name = args.extract_plain_text().strip()
+
+    len_username = len(user_name.encode('gbk'))
+    if len_username > 20:
+        await remaname.finish("道号长度过长，请修改后重试！")
+
     if sql_message.get_user_message(user_id) is None:
-        await in_closing.finish("修仙界没有道友的信息，请输入【我要修仙】加入！")
+        await remaname.finish("修仙界没有道友的信息，请输入【我要修仙】加入！")
 
     mes = sql_message.update_user_name(user_id, user_name)
     await remaname.finish(mes)
@@ -468,7 +473,8 @@ async def get_group_id(session_id):
 async def update_level(event: GroupMessageEvent):
     """突破"""
     user_id = event.get_user_id()
-    user_msg = sql_message.get_user_message(user_id)
+    user_msg = sql_message.get_user_message(user_id)  # 用户信息
+    user_leveluprate =  int(user_msg.level_up_rate)  # 用户失败次数加成
 
     level_cd = user_msg.level_up_cd
     if level_cd:
@@ -487,7 +493,7 @@ async def update_level(event: GroupMessageEvent):
     exp = user_msg.exp  # 用户修为
     level_rate = jsondata.level_rate_data()[level_name]  # 对应境界突破的概率
 
-    le = OtherSet().get_type(exp, level_rate, level_name)
+    le = OtherSet().get_type(exp, level_rate + user_leveluprate, level_name)
 
     if le == "失败":
         # 突破失败
@@ -500,13 +506,21 @@ async def update_level(event: GroupMessageEvent):
         now_exp = int(int(exp) * (percentage / 100))
 
         sql_message.update_j_exp(user_id, now_exp)  # 更新用户修为
-        await level_up.finish("道友突破失败,境界受损,修为减少{}，过段时间再突破吧！".format(now_exp))
+
+        update_rate = 1 if int(level_rate * 0.05) <= 1 else int(level_rate * 0.05)  # 失败增加突破几率
+
+        sql_message.update_levelrate(user_id, user_leveluprate + update_rate)
+
+        await level_up.finish("道友突破失败,境界受损,修为减少{}，下次突破成功率增加{}%，道友不要放弃！".format(now_exp, update_rate))
 
     elif type(le) == list:
         # 突破成功
         sql_message.updata_level(user_id, le[0])  # 更新境界
         sql_message.update_power2(user_id)  # 更新战力
         sql_message.updata_level_cd(user_id)  # 更新CD
+
+        sql_message.update_levelrate(user_id, 0)
+
         await level_up.finish("恭喜道友突破{}成功".format(le[0]))
     else:
         # 最高境界
@@ -715,14 +729,13 @@ async def _(event: GroupMessageEvent, args: Message = CommandArg()):
                 f"进行中的悬赏令【{user_cd_message.scheduled_time}】，已结束，请输入【悬赏令结算】结算任务信息！",
                 at_sender=True,
             )
-            
+
 #偷灵石
 @steal_stone.handle()
 async def _(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
     user_id = event.get_user_id()
     user_message = sql_message.get_user_message(user_id)
     steal_user = None
-    steal_user_stone = None
 
     if user_message is None:
         await steal_stone.finish('修仙界没有你的信息！请输入我要修仙，踏入修行')
@@ -747,23 +760,35 @@ async def _(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
             await steal_stone.finish("请不要偷自己刷成就！")
         else:
             steal_user = sql_message.get_user_message(steal_qq)
-            steal_user_stone = steal_user.stone
+
     if steal_user:
+        # 判断是否存在用户
         steal_success = random.randint(0, 100)
         result = OtherSet().get_power_rate(user_message.power, steal_user.power)
+
+
+        print("result",result)
+        print("result", type(result))
         if isinstance(result, int):
-            if int(steal_success) < OtherSet().get_power_rate(user_message.stone, steal_user.stone):
-                sql_message.update_ls(user_id, coststone_num, 2)  # 减少手续费
+            # 判断返回类型是否为int
+
+            if int(steal_success) > result:
+                # 判断是否偷窃成功，例：成功率为80，steal_success>80则失败
+                sql_message.update_ls(user_id, coststone_num, 2)  # 偷窃失败扣费
                 await steal_stone.finish('道友偷窃失手了，被对方发现并被派去华哥厕所义务劳工！')
 
-            get_stone = random.randint(5, 100)
-            sql_message.update_ls(user_id, coststone_num, 2)  # 减少手续费
+            steal_user_stone = steal_user.stone  # 被偷用户的灵石
+            get_stone = random.randint(5, 100)   # 偷取的灵石
+            sql_message.update_ls(user_id, coststone_num, 2)  # 偷窃失败扣费
 
             if int(get_stone) > int(steal_user_stone):
+                # 如果偷取的灵石数量大于对方身上的灵石
+
                 sql_message.update_ls(user_id, steal_user_stone, 1)  # 增加偷到的灵石
                 sql_message.update_ls(steal_qq, steal_user_stone, 2)  # 减少被偷的人的灵石
                 await steal_stone.finish(
                     "{}道友已经被榨干了~".format(steal_user.user_name))
+
             else:
                 sql_message.update_ls(user_id, get_stone, 1)  # 增加偷到的灵石
                 sql_message.update_ls(steal_qq, get_stone, 2)  # 减少被偷的人的灵石
@@ -771,21 +796,22 @@ async def _(bot: Bot, event: GroupMessageEvent, args: Message = CommandArg()):
                     "共偷取{}道友{}枚灵石！".format(steal_user.user_name, get_stone))
         else:
             await steal_stone.finish(result)
-
     else:
         await steal_stone.finish("对方未踏入修仙界，不要对杂修出手！")
 
     if nick_name:
         give_message = sql_message.get_user_message2(nick_name[0])
-        give_user_stone = give_message.stone
+
         if give_message:
             steal_success2 = random.randint(0, 100)
 
             result = OtherSet().get_power_rate(user_message.power, give_message.power)
             if isinstance(result, int):
-                if int(steal_success2) < result:
+                if int(steal_success2) > result:
                     sql_message.update_ls(user_id, coststone_num, 2)  # 减少手续费
                     await steal_stone.finish('道友偷窃失手了，被对方发现并被派去华哥厕所义务劳工！')
+
+                give_user_stone = give_message.stone
                 get_stone2 = random.randint(5, 100)
                 sql_message.update_ls(user_id, coststone_num, 2)  # 减少手续费
                 if int(get_stone2) > int(give_user_stone):
@@ -845,3 +871,21 @@ async def _(event: GroupMessageEvent, args: Message = CommandArg()):
             await give_stone.finish("对方未踏入修仙界，不可赠送！")
     else:
         await give_stone.finish("未获取道号信息，请输入正确的道号！")
+
+
+async def data_check(bot, event):
+    user_qq = event.get_user_id()
+    group_id = await get_group_id(event.get_session_id())
+    msg = sql_message.get_user_message(user_qq)
+
+    if msg:
+        pass
+    else:
+        await bot.send(event=event, message=f"没有您的信息，输入【我要修仙】加入！")
+        raise MsgError
+
+    return user_qq, group_id, msg
+
+
+class MsgError(ValueError):
+    pass
