@@ -11,23 +11,36 @@ DATABASE =Path() / "data" / "xiuxian"
 
 xiuxian_data = namedtuple("xiuxian_data", ["no", "user_id", "linggen", "level"])
 
-UserDate = namedtuple("UserDate", ["id", "user_id", "stone", "root","root_type","level","power","create_time","is_sign","exp","user_name","level_up_cd"])
+UserDate = namedtuple("UserDate",
+                      ["id", "user_id", "stone", "root", "root_type", "level", "power", "create_time", "is_sign", "exp",
+                       "user_name", "level_up_cd", "level_up_rate"])
 UserCd = namedtuple("UserCd", [ "user_id", "type", "create_time", "scheduled_time"])
 
+num = '578043031'
 
 class XiuxianDateManage:
+    _instance = {}
+    _has_init = {}
+
+
+    def __new__(cls):
+        if cls._instance.get(num) is None:
+            cls._instance[num] = super(XiuxianDateManage, cls).__new__(cls)
+        return cls._instance[num]
+
     def __init__(self):
-        self.database_path = DATABASE
-        if not self.database_path.exists():
-            self.database_path.mkdir(parents=True)
-            self.database_path /= "xiuxian.db"
-            self.conn = sqlite3.connect(self.database_path)
-            # self._create_file()
-        else:
-            self.database_path /= "xiuxian.db"
-            self.conn = sqlite3.connect(self.database_path)
-        print(f"数据库已连接！")
-        # self._check_data()
+        if not XiuxianDateManage._has_init.get(num):
+            self.database_path = DATABASE
+            if not self.database_path.exists():
+                self.database_path.mkdir(parents=True)
+                self.database_path /= "xiuxian.db"
+                self.conn = sqlite3.connect(self.database_path)
+                # self._create_file()
+            else:
+                self.database_path /= "xiuxian.db"
+                self.conn = sqlite3.connect(self.database_path)
+            print(f"数据库已连接！")
+            self._check_data()
 
     def close(self):
         self.conn.close()
@@ -49,44 +62,48 @@ class XiuxianDateManage:
     def _check_data(self):
         """检查数据完整性"""
         c = self.conn.cursor()
-        try:
-            c.execute(f"select count(1) from user_cd")
-        except:
-            c.execute("""CREATE TABLE user_cd
-                                    (user_id       INTEGER PRIMARY KEY UNIQUE,
-                                    type           INTEGER,
-                                    create_time    INTEGER,
-                                    scheduled_time INTEGER);""")
 
-        # sql = "select * FROM level where name=?"
-        # c.execute(sql, ("融合灵根",))
-        # result = c.fetchone()
-        # if result:
-        #     pass
-        # else:
-        #     c.execute(f"DELETE from level")
-        #     c.executescript(f"""INSERT INTO "main"."level" ("name", "power") VALUES ('江湖好手', 100);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('练气境初期', 1000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('练气境中期', 2000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('练气境圆满', 3000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('筑基境初期', 8000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('筑基境中期', 9000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('筑基境圆满', 10000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('伪灵根', 0.8);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('真灵根', 1);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('天灵根', 1.2);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('变异灵根', 1.2);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('超灵根', 1.4);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('龙灵根', 1.3);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('混沌灵根', 1.5);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('融合灵根', 1.5);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('结丹境初期', 20000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('结丹境中期', 40000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('结丹境圆满', 80000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('元婴境初期', 160000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('元婴境中期', 360000);
-        # INSERT INTO "main"."level" ("name", "power") VALUES ('元婴境圆满', 720000);""")
+        for i in XiuConfig().sql_table:
+            if i == "user_xiuxian":
+                try:
+                    c.execute(f"select count(1) from {i}")
+                except sqlite3.OperationalError:
+                    c.execute("""CREATE TABLE "user_xiuxian" (
+      "id" INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
+      "user_id" INTEGER NOT NULL,
+      "stone" integer DEFAULT 0,
+      "root" TEXT,
+      "root_type" TEXT,
+      "level" TEXT,
+      "power" integer DEFAULT 0,
+      "create_time" integer,
+      "is_sign" integer DEFAULT 0,
+      "exp" integer DEFAULT 0,
+      "user_name" TEXT DEFAULT NULL,
+      "level_up_cd" integer DEFAULT NULL,
+      "level_up_rate" integer DEFAULT NULL
+    );""")
+            elif i == "user_cd":
+                try:
+                    c.execute(f"select count(1) from {i}")
+                except sqlite3.OperationalError:
+                    c.execute("""CREATE TABLE "user_cd" (
+  "user_id" INTEGER NOT NULL,
+  "type" integer DEFAULT 0,
+  "create_time" integer DEFAULT NULL,
+  "scheduled_time" integer,
+  PRIMARY KEY ("user_id")
+);""")
 
+        for i in XiuConfig().sql_user_xiuxian:
+            try:
+                c.execute(f"select {i} from user_xiuxian")
+            except sqlite3.OperationalError:
+                sql = f"ALTER TABLE user_xiuxian ADD COLUMN {i} INTEGER DEFAULT 0;"
+                print(sql)
+                c.execute(sql)
+
+        self.conn.commit()
 
     @classmethod
     def close_dbs(cls):
@@ -189,7 +206,7 @@ class XiuxianDateManage:
         cur = self.conn.cursor()
         level = jsondata.level_data()
         root = jsondata.root_data()
-        sql = f"UPDATE user_xiuxian SET power=exp*?*? WHERE user_id=?"
+        sql = f"UPDATE user_xiuxian SET power=round(exp*?*?,0) WHERE user_id=?"
         cur.execute(sql, (root[UserMessage.root_type]["type_speeds"], level[UserMessage.level]["spend"], user_id))
         self.conn.commit()
 
@@ -378,7 +395,7 @@ class XiuxianDateManage:
 
     def power_top(self):
         """战力排行榜"""
-        sql = f"SELECT user_name,stone FROM user_xiuxian WHERE user_name is NOT NULL ORDER BY power DESC LIMIT 10"
+        sql = f"SELECT user_name,power FROM user_xiuxian WHERE user_name is NOT NULL ORDER BY power DESC LIMIT 10"
         cur = self.conn.cursor()
         cur.execute(sql, )
         result = cur.fetchall()
@@ -386,7 +403,7 @@ class XiuxianDateManage:
         num = 0
         for i in result:
             num += 1
-            mess += f"第{num}位  {i[0]}  战力：{i[1]}枚\n"
+            mess += f"第{num}位  {i[0]}  战力：{i[1]}\n"
 
         return mess
 
@@ -412,6 +429,13 @@ class XiuxianDateManage:
         cur.execute(sql, (the_type, now_time, sc_time, user_id))
         self.conn.commit()
 
+    def update_levelrate(self, user_id, rate):
+        """更新突破成功率"""
+        sql = f"UPDATE user_xiuxian SET level_up_rate=? where user_id=?"
+        cur = self.conn.cursor()
+        cur.execute(sql, (rate, user_id))
+        self.conn.commit()
+
 
 
 class XiuxianJsonDate:
@@ -579,30 +603,52 @@ class OtherSet(XiuConfig):
         return (day * 24 * 60 * 60) + sec
 
     def fight(self,player1=None,player2=None):
+        import random
         player1 = {'HP': 100,
                    "ROOT_RATE": 1,
                    "LEVEL_RATE": 1,
                    "COMBO": 0,
                    "ATK": 12,
-                   "AC": 20}
+                   "AC": 1,
+                   "MP": 100}
 
         player2 = {'HP': 100,
                    "ROOT_RATE": 1.2,
                    "LEVEL_RATE": 1,
                    "COMBO": 0,
                    "ATK": 10,
-                   "AC": 19}
+                   "AC": 1,
+                   "MP": 100}
 
         HP_SEND = True
-        while HP_SEND is True:
+        while HP_SEND:
             player1_gj = (random.randint(1, 10) + player1['ATK']) * player1["ROOT_RATE"] * player1["LEVEL_RATE"]
             player2_gj = (random.randint(1, 10) + player2['ATK']) * player2["ROOT_RATE"] * player2["LEVEL_RATE"]
 
-            player2['HP'] = player2['HP'] - (int(player1_gj) - player2["AC"])
-            print(player2['HP'])
-            HP_SEND = False
-        else:
-            print('222')
+            # 造成的伤害
+            play1_sh: int = int(player1_gj) - player2['AC']
+            play2_sh: int = int(player2_gj) - player1['AC']
+
+            print(f"play1发起攻击，造成伤害{play1_sh}")
+            player2['HP'] = player2['HP'] - play1_sh
+            print(f"play2剩余血量{player2['HP']}")
+
+            if player2['HP'] <= 0:
+                print("play1胜利")
+                break
+
+            import time
+            time.sleep(1)
+            print(f"play2发起攻击，造成伤害{play2_sh}")
+            player1['HP'] = player1['HP'] - play2_sh
+            print(f"play1剩余血量{player1['HP']}\n")
+            time.sleep(1)
+            if player1['HP'] <= 0:
+                print("play2胜利")
+                break
+
+            if player1['HP'] <= 0 or player2['HP'] <= 0:
+                break
             
     def get_power_rate(self, mind, other):
         power_rate = mind / (other + mind)
@@ -616,7 +662,7 @@ class OtherSet(XiuConfig):
 
 
 if __name__ == '__main__':
-    print(OtherSet().date_diff("2022-09-08 00:42:56.740255","2022-09-08 00:42:56.740255"))
+    print(OtherSet().fight)
     # paths = r"G:\yuzi_bot\yuzi_bot\data\xiuxian\悬赏令.json"
     # with open(paths, 'r', encoding='utf-8') as e:
     #     a = e.read()
